﻿/// <reference path="data.js" />

(function (lightSwitchApplication) {

    var $Screen = msls.Screen,
        $defineScreen = msls._defineScreen,
        $DataServiceQuery = msls.DataServiceQuery,
        $toODataString = msls._toODataString,
        $defineShowScreen = msls._defineShowScreen;

    function Home(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the Home screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Sessions" type="msls.VisualCollection" elementType="msls.application.Session">
        /// Gets the sessions for this screen.
        /// </field>
        /// <field name="FilterByRoom" type="msls.application.Room">
        /// Gets or sets the filterByRoom for this screen.
        /// </field>
        /// <field name="FilterBySpeaker" type="msls.application.Speaker">
        /// Gets or sets the filterBySpeaker for this screen.
        /// </field>
        /// <field name="FilterByTimeSlot" type="msls.application.Timeslot">
        /// Gets or sets the filterByTimeSlot for this screen.
        /// </field>
        /// <field name="FilterByTrack" type="msls.application.Track">
        /// Gets or sets the filterByTrack for this screen.
        /// </field>
        /// <field name="NextSessions" type="msls.VisualCollection" elementType="msls.application.Session">
        /// Gets the nextSessions for this screen.
        /// </field>
        /// <field name="Tracks" type="msls.VisualCollection" elementType="msls.application.Track">
        /// Gets the tracks for this screen.
        /// </field>
        /// <field name="FavoriteSessions" type="msls.VisualCollection" elementType="msls.application.FavoriteSession">
        /// Gets the favoriteSessions for this screen.
        /// </field>
        /// <field name="details" type="msls.application.Home.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "Home", parameters);
    }

    function ViewSession(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the ViewSession screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Session" type="msls.application.Session">
        /// Gets or sets the session for this screen.
        /// </field>
        /// <field name="IsFavorite" type="Boolean">
        /// Gets or sets the isFavorite for this screen.
        /// </field>
        /// <field name="details" type="msls.application.ViewSession.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "ViewSession", parameters);
    }

    msls._addToNamespace("msls.application", {

        Home: $defineScreen(Home, [
            {
                name: "Sessions", kind: "collection", elementType: lightSwitchApplication.Session,
                createQuery: function (RoomId, SpeakerId, TimeSlotId, TrackId) {
                    return this.dataWorkspace.ApplicationData.Sessions.filter("((" + ((RoomId === undefined || RoomId === null) ? "true" : "(Room/Id eq " + $toODataString(RoomId, "Int32?") + ")") + " and " + ((SpeakerId === undefined || SpeakerId === null) ? "true" : "(Speaker/Id eq " + $toODataString(SpeakerId, "Int32?") + ")") + ") and " + ((TimeSlotId === undefined || TimeSlotId === null) ? "true" : "(Timeslot/Id eq " + $toODataString(TimeSlotId, "Int32?") + ")") + ") and " + ((TrackId === undefined || TrackId === null) ? "true" : "(Track/Id eq " + $toODataString(TrackId, "Int32?") + ")") + "").orderBy("Title").expand("Level").expand("Room").expand("Speaker").expand("Timeslot").expand("Track").expand("SessionType");
                }
            },
            { name: "FilterByRoom", kind: "local", type: lightSwitchApplication.Room },
            { name: "FilterBySpeaker", kind: "local", type: lightSwitchApplication.Speaker },
            { name: "FilterByTimeSlot", kind: "local", type: lightSwitchApplication.Timeslot },
            { name: "FilterByTrack", kind: "local", type: lightSwitchApplication.Track },
            {
                name: "NextSessions", kind: "collection", elementType: lightSwitchApplication.Session,
                createQuery: function () {
                    return this.dataWorkspace.ApplicationData.NextSessions().expand("Speaker").expand("Timeslot").expand("Level").expand("Room").expand("Track");
                }
            },
            {
                name: "Tracks", kind: "collection", elementType: lightSwitchApplication.Track,
                createQuery: function () {
                    return this.dataWorkspace.ApplicationData.Tracks;
                }
            },
            {
                name: "FavoriteSessions", kind: "collection", elementType: lightSwitchApplication.FavoriteSession,
                createQuery: function () {
                    return this.dataWorkspace.ApplicationData.FavoriteSessions.orderBy("Session/Timeslot/StartTime").expand("Session").expand("Session.Timeslot");
                }
            }
        ], [
            { name: "BrowseByTrack_ItemTap" }
        ]),

        ViewSession: $defineScreen(ViewSession, [
            { name: "Session", kind: "local", type: lightSwitchApplication.Session },
            { name: "IsFavorite", kind: "local", type: Boolean }
        ], [
            { name: "Favorite" },
            { name: "Unfavorite" }
        ]),

        showHome: $defineShowScreen(function showHome(options) {
            /// <summary>
            /// Asynchronously navigates forward to the Home screen.
            /// </summary>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.<br/>+ Signature: beforeShown(screen)<br/>- afterClosed: a function that is called after boundary behavior has been applied and the screen has been closed.<br/>+ Signature: afterClosed(screen, action : msls.NavigateBackAction)
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 0, 0);
            return lightSwitchApplication.showScreen("Home", parameters, options);
        }),

        showViewSession: $defineShowScreen(function showViewSession(Session, options) {
            /// <summary>
            /// Asynchronously navigates forward to the ViewSession screen.
            /// </summary>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.<br/>+ Signature: beforeShown(screen)<br/>- afterClosed: a function that is called after boundary behavior has been applied and the screen has been closed.<br/>+ Signature: afterClosed(screen, action : msls.NavigateBackAction)
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 0, 1);
            return lightSwitchApplication.showScreen("ViewSession", parameters, options);
        })

    });

}(msls.application));
